@@ -4,8 +4,8 @@ __author__ = 'Timo Kats'
 
 # local imports
 
-from lib.lexical_analysis import *
-from lib.split import *
+from redex.lexical_analysis import *
+from redex.split import *
 
 # main functionalities
 
